@@ -847,9 +847,7 @@ class SevenZipFile(contextlib.AbstractContextManager):
         del self.sig_header
 
     @staticmethod
-    def _make_file_info(  # noqa
-        target: pathlib.Path, arcname: str | None = None, dereference: bool = False
-    ) -> FileInfoDict:
+    def _make_file_info(target: pathlib.Path, arcname: str | None = None, dereference: bool = False) -> FileInfoDict:
         origin = target
         filename = pathlib.Path(arcname).as_posix() if arcname else target.as_posix()
         target = target.resolve() if dereference else target
@@ -1409,6 +1407,8 @@ class Worker:
                 self._check(fp, just_check, src_end)
                 just_check = []
                 if not isinstance(fileish, MemIO):
+                    if not is_path_valid(fileish, path):
+                        raise Bad7zFile(f"Specified path is bad: {fileish}")
                     fileish.parent.mkdir(parents=True, exist_ok=True)
                 if not f.emptystream:
                     if f.is_junction and not isinstance(fileish, MemIO) and sys.platform == "win32":
